==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ConverterImageType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p729701_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p909447_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The settings are used when converting images if the source file is an image. If the source file is another format that may contain images, then these settings may not apply.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterImageType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterImageType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="maintainAspectRatio" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterImageType")
public class ConverterImageType {

    @XmlAttribute(name = "maintainAspectRatio")
    protected Boolean maintainAspectRatio;

    /**
     * Gets the value of the maintainAspectRatio property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isMaintainAspectRatio() {
        if (maintainAspectRatio == null) {
            return false;
        } else {
            return maintainAspectRatio;
        }
    }

    /**
     * Sets the value of the maintainAspectRatio property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMaintainAspectRatio(boolean value) {
        this.maintainAspectRatio = value;
    }

    public boolean isSetMaintainAspectRatio() {
        return (this.maintainAspectRatio!= null);
    }

    public void unsetMaintainAspectRatio() {
        this.maintainAspectRatio = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterImageType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p383362_="https://jakarta.ee/xml/ns/jaxb" xmlns:p837822_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The settings are used when converting images if the source file is an image. If the source file is another format that may contain images, then these settings may not apply.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterImageType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterImageType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="maintainAspectRatio" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterImageType")
public class ConverterImageType {

    @XmlAttribute(name = "maintainAspectRatio")
    protected Boolean maintainAspectRatio;

    /**
     * Gets the value of the maintainAspectRatio property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isMaintainAspectRatio() {
        if (maintainAspectRatio == null) {
            return false;
        } else {
            return maintainAspectRatio;
        }
    }

    /**
     * Sets the value of the maintainAspectRatio property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMaintainAspectRatio(boolean value) {
        this.maintainAspectRatio = value;
    }

    public boolean isSetMaintainAspectRatio() {
        return (this.maintainAspectRatio!= null);
    }

    public void unsetMaintainAspectRatio() {
        this.maintainAspectRatio = null;
    }

}
